# muyi

Some useful utils for GNNs and Deep Learning.

```bash
pip install muyi
```

## utils

1. `color_print(content)`
2. `save_pic_iterly(pic_name, postfix, info)`
3. `read_csv_tqdm(path, **kwargs)`

## graph

1. `pyg_data_to_dgl_graph(pyg_data_obj)`

## gpu

1. `get_gpu_memory_usage()`
2. `display_gpu_memory_usage()`
